@@ -54,25 +54,13 @@ TIMESTAMP = datetime.datetime.now().strftime("%A, %d. %B %Y %I:%M%p")
 NO_FILES = """You did not specify any input data. Use the flag '--dir', followed
 by the path to a directory, to point to a directory which contain your
 multiple sequence alignments (MSAs) and input trees."""
-# with open("VERSION") as version_file:
-#     version = version_file.read().strip()
-version = "1.1.2"
+# with open("phylopypruner/VERSION") as version_file:
+#     version = version_file.read()
+version = "1.1.16"
 ABOUT = report.underline("PhyloPyPruner version {}".format(version))
 ABOUT_LOG = "PhyloPyPruner version {}\n{}\n{}".format(
     version, TIMESTAMP, "-" * len(TIMESTAMP))
 
-def _validate_input(msa, tree, tree_path):
-    "Test to see if MSA and tree entries matches."
-    descriptions = list(msa.iter_descriptions())
-    names = list(tree.iter_names())
-
-    if set(descriptions).intersection(names) < set(descriptions):
-        print("example tree names:", names[:2], file=sys.stderr)
-        print("example sequences:", descriptions[:2], file=sys.stderr)
-        report.error("MSA names don't match tree \n   {}\n   {}".format(
-            msa.filename, tree_path))
-
-
 def _no_files(args):
     "Returns True if the required files are not provided."
     return not args.dir
@@ -152,105 +140,6 @@ has to be a positive number")
         sys.exit()
 
 
-def _run(settings, msa, tree):
-    """
-    Takes a dictionary that specifies a set of settings as an input. The
-    dictionary should contain the following keys: msa, tree, min_taxa, min_len,
-    min_support, trim_lb, outgroup, root, mask, and prune. Runs PhyloPyPruner
-    once using these settings.
-    """
-    # test to see if the entries in the MSA and tree matches
-    _validate_input(msa, tree, settings.nw_file)
-
-    run_log = log.Log(version, msa, tree, settings)
-
-    # exclude taxa within the list settings.exclude
-    if settings.exclude:
-        tree = filtering.exclude(tree, settings.exclude)
-
-    if filtering.too_few_otus(tree, settings.min_taxa):
-        return run_log
-
-    # remove short sequences
-    if settings.min_len:
-        run_log.trimmed_seqs = filtering.trim_short_seqs(
-            msa, tree, settings.min_len)
-
-    if filtering.too_few_otus(tree, settings.min_taxa):
-        return run_log
-
-    # trim long branches
-    if settings.trim_lb:
-        run_log.lbs_removed = list(filtering.prune_long_branches(
-            tree, settings.trim_lb))
-
-    if filtering.too_few_otus(tree, settings.min_taxa):
-        return run_log
-
-    # trim zero length branches
-    if settings.trim_zero_len:
-        run_log.ultra_short_branches = filtering.trim_zero_len_branches(
-            tree, settings.trim_zero_len)
-
-    if filtering.too_few_otus(tree, settings.min_taxa):
-        return run_log
-
-    # collapse weakly supported nodes into polytomies
-    if settings.min_support:
-        run_log.collapsed_nodes = filtering.collapse_nodes(
-            tree, settings.min_support)
-
-    # mask monophyletic groups
-    if settings.mask:
-        if settings.mask == "pdist":
-            tree, masked_seqs = mask_monophylies.pairwise_distance(tree)
-        elif settings.mask == "longest":
-            tree, masked_seqs = mask_monophylies.longest_isoform(msa, tree)
-        run_log.monophylies_masked = masked_seqs
-
-    # trim divergent sequences
-    if settings.trim_divergent:
-        run_log.divergent, run_log.divergent_removed = decontamination.trim_divergent(
-            tree, settings.trim_divergent, settings.include)
-
-    if filtering.too_few_otus(tree, settings.min_taxa):
-        return run_log
-
-    # root by outgroup
-    rooted = False   # True if outgroup rooting is successful
-    if settings.outgroup:
-        if not settings.prune == "MO":
-            tree, rooted = root.outgroup(tree, settings.outgroup)
-
-    # root the tree by midpoint rooting
-    if not rooted and settings.root:
-        if settings.root == "midpoint":
-            tree = root.midpoint(tree)
-
-    # mask monophyletic groups
-    if settings.mask:
-        if settings.mask == "pdist":
-            tree, masked_seqs = mask_monophylies.pairwise_distance(tree)
-        elif settings.mask == "longest":
-            tree, masked_seqs = mask_monophylies.longest_isoform(msa, tree)
-        run_log.monophylies_masked.update(masked_seqs)
-
-    run_log.masked_tree = tree
-
-    # get a list of paralogs
-    run_log.paralogs = tree.paralogs()
-
-    # prune paralogs
-    run_log.orthologs = prune_paralogs(settings.prune, tree,
-                                   settings.min_taxa, settings.outgroup)
-
-    if settings.force_inclusion:
-        run_log.orthologs = filtering.force_inclusion(
-            run_log.orthologs, settings.force_inclusion)
-
-    return run_log
-
-
 def file_pairs_from_directory(directory):
     """Takes the path to a directory as an input. Finds corresponding files, or
     file pairs, where each pair consists of the path to a multiple sequence
@@ -335,10 +224,6 @@ def parse_args():
                         action="store_true",
                         help="overwrite pre-existing output files without\
                               asking")
-    parser.add_argument("--no-plot",
-                        default=False,
-                        action="store_true",
-                        help="do not generate any plots (faster)")
     parser.add_argument("--wrap",
                         metavar="<number>",
                         default=None,
@@ -486,6 +371,16 @@ def parse_args():
                        help="exclude each OTU one by one, rerun the whole\
                              analysis and generate statistics for each\
                              subsample")
+
+    group = parser.add_argument_group("flow-control")
+    parser.add_argument("--no-plot",
+                        default=False,
+                        action="store_true",
+                        help="do not generate any plots (faster)")
+    parser.add_argument("--supermatrix",
+                        default=False,
+                        action="store_true",
+                        help="concatenate output into a supermatrix (slower)")
     return parser.parse_args(args=None if sys.argv[1:] else ['--help'])
 
 
