@@ -12,8 +12,8 @@ try:
     plt.rcParams.update({'figure.max_open_warning': 0})
     MATPLOTLIB = True
 except ImportError:
-    report.tip("install Matplotlib (https://matplotlib.org/) to generate \
-plots")
+#     report.tip("install Matplotlib (https://matplotlib.org/) to generate \
+# plots")
     MATPLOTLIB = False
 
 OCCUPANCY_PLOT_FILE = "occupancy_matrix.png"
