@@ -111,9 +111,14 @@ class Summary(object):
 
                 for sequence in msa.sequences:
                     for index in range(0, len(presence))[::-1]:
-                        if not presence[index]:
-                            sequence.sequence_data = remove_position_from_str(
-                                sequence.sequence_data, index)
+                        try:
+                            if not presence[index]:
+                                sequence.sequence_data = remove_position_from_str(
+                                    sequence.sequence_data, index)
+                        except:
+                            report.error("uneven alignment length encountered \
+                                          in MSA {}".format(msa.filename))
+                            exit(1)
 
         return self
 
